import 'dart:convert';

import 'package:test/test.dart';
import 'package:yona_crypto/crypto.dart';
import 'package:yona_crypto/utils.dart';

void main() {
  test("deriveKey", () async {
    var sk1 = genSK();
    var sk2 = genSK();
    assert(sk2 != sk1);
    var pk1 = derivePK(sk1);
    var pk2 = derivePK(sk2);
    var k1 = await deriveKey(sk1, pk2);
    var k2 = await deriveKey(sk2, pk1);
    assert(k1 == k2);
  });
  test("encryptAndDecrypt", () async {
    var text = randBytes(9999);
    var key = randKey();
    var decoded = await decrypt(key, await encrypt(key, text));
    assert(equal(text, decoded));
  });
  test("digest", () {
    var orders = [
      [
        "2f1d49c01e52ddb7875b4b",
        "ZL7E3zc0zzKE3-8lmSS7D1gr96aXcsYfss62WrK7icg",
        false
      ],
      [
        "6b86b273ff34fce19d6b804eff5a3f5747ada4eaa22f1d49c01e52ddb7875b4b",
        "4LxhTk_QNaSIYZeZhTsHUUPe6llsR3uNwHfjCcD-Quk=",
        true
      ],
      [
        "ce19d6b804eff5a3f57ada4eaa22f1d49c01e52ddb7875b4b",
        "Vx2azW0vz3unOAtJ1hza8j-1oaSDrP1_HsHCG-1ZDf0=",
        true
      ]
    ];
    for (var order in orders) {
      var hash = digest(utf8.encode(order[0] as String));
      assert(order[2] == (order[1] == hash.toString()));
    }
  });
  test("SignAndVerify", () {
    var sk = genSK();
    var pk = derivePK(sk);
    var data = randBytes(100);
    var sig = sign(sk, data);
    verify(data, sig, pk);
  });

  //TODO test compatibility with go impl
}
